package com.ruoyi.jarvis.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.jarvis.mapper.XbGroupMapper;
import com.ruoyi.jarvis.domain.XbGroup;
import com.ruoyi.jarvis.service.IXbGroupService;

/**
 * 线报群信息Service业务层处理
 *
 * @author ruoyi
 */
@Service
public class XbGroupServiceImpl implements IXbGroupService
{
    @Autowired
    private XbGroupMapper xbGroupMapper;

    /**
     * 查询线报群信息
     *
     * @param id 线报群信息主键
     * @return 线报群信息
     */
    @Override
    public XbGroup selectXbGroupById(Integer id)
    {
        return xbGroupMapper.selectXbGroupById(id);
    }

    /**
     * 查询线报群信息列表
     *
     * @param xbGroup 线报群信息
     * @return 线报群信息
     */
    @Override
    public List<XbGroup> selectXbGroupList(XbGroup xbGroup)
    {
        return xbGroupMapper.selectXbGroupList(xbGroup);
    }

    /**
     * 新增线报群信息
     *
     * @param xbGroup 线报群信息
     * @return 结果
     */
    @Override
    public int insertXbGroup(XbGroup xbGroup)
    {
        return xbGroupMapper.insertXbGroup(xbGroup);
    }

    /**
     * 修改线报群信息
     *
     * @param xbGroup 线报群信息
     * @return 结果
     */
    @Override
    public int updateXbGroup(XbGroup xbGroup)
    {
        return xbGroupMapper.updateXbGroup(xbGroup);
    }

    /**
     * 批量删除线报群信息
     *
     * @param ids 需要删除的线报群信息主键
     * @return 结果
     */
    @Override
    public int deleteXbGroupByIds(Integer[] ids)
    {
        return xbGroupMapper.deleteXbGroupByIds(ids);
    }

    /**
     * 删除线报群信息信息
     *
     * @param id 线报群信息主键
     * @return 结果
     */
    @Override
    public int deleteXbGroupById(Integer id)
    {
        return xbGroupMapper.deleteXbGroupById(id);
    }
}
