package com.ruoyi.web.controller.jarvis;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.jarvis.enums.GroupType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jarvis.domain.XbGroup;
import com.ruoyi.jarvis.service.IXbGroupService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

import static com.ruoyi.common.utils.DateUtils.getNowDate;

/**
 * 线报群信息Controller
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/jarvis/xbgroup")
public class XbGroupController extends BaseController
{
    @Autowired
    private IXbGroupService xbGroupService;

    @GetMapping("/select/groupType")
    public AjaxResult getGroupTypeOptions() {
        return AjaxResult.success(GroupType.getSelectItems());
    }
    @GetMapping("/select/groupName")
    public AjaxResult getGroupNameOptions() {
        List<XbGroup> xbGroups = xbGroupService.selectXbGroupList(null);
        ArrayList<HashMap<String, String>> hashMaps = new ArrayList<>();

        for (XbGroup xbGroup : xbGroups) {
            hashMaps.add(new HashMap<String, String>() {{
                put("value", xbGroup.getWxid());
                put("label", xbGroup.getName());
            }});
        }
        return AjaxResult.success(hashMaps);
    }

    /**
     * 查询线报群信息列表
     */
    @GetMapping("/list")
    public TableDataInfo list(XbGroup xbGroup)
    {
        startPage();
        List<XbGroup> list = xbGroupService.selectXbGroupList(xbGroup);
        TableDataInfo dataTable = getDataTable(list);
        if (!dataTable.getRows().isEmpty()) {
             @SuppressWarnings("unchecked")
             List<XbGroup> rows = (List<XbGroup>) dataTable.getRows();
            for (XbGroup xbGroupCache : rows) {
                xbGroupCache.setGroupTypeName(GroupType.getName(xbGroupCache.getGroupType()));
            }
            dataTable.setRows(rows);
        }

        return dataTable;
    }

    /**
     * 导出线报群信息列表
     */
    @Log(title = "线报群信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, XbGroup xbGroup)
    {
        List<XbGroup> list = xbGroupService.selectXbGroupList(xbGroup);
        ExcelUtil<XbGroup> util = new ExcelUtil<XbGroup>(XbGroup.class);
        util.exportExcel(response, list, "线报群信息数据");
    }

    /**
     * 获取线报群信息详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(xbGroupService.selectXbGroupById(id));
    }

    /**
     * 新增线报群信息
     */
    @Log(title = "线报群信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody XbGroup xbGroup)
    {
        xbGroup.setCreateDate(getNowDate());
        return toAjax(xbGroupService.insertXbGroup(xbGroup));
    }

    /**
     * 修改线报群信息
     */
    @Log(title = "线报群信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody XbGroup xbGroup)
    {
        xbGroup.setUpdateDate(getNowDate());
        return toAjax(xbGroupService.updateXbGroup(xbGroup));
    }

    /**
     * 删除线报群信息
     */
    @Log(title = "线报群信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(xbGroupService.deleteXbGroupByIds(ids));
    }
}
